pub struct ListView<T>{ /* private fields */ }Expand description
ListView for displaying multiple objects
Implementations
Sourceimpl<T> ListView<T>
impl<T> ListView<T>
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new ListView with default settings.
Uses JsonSerializer by default. Use with_serializer to provide a custom serializer.
Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};
#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
id: Option<i64>,
title: String,
}
#[derive(Clone)]
struct ArticleFields;
impl reinhardt_db::orm::FieldSelector for ArticleFields {
fn with_alias(self, _alias: &str) -> Self {
self
}
}
impl Model for Article {
type PrimaryKey = i64;
type Fields = ArticleFields;
fn table_name() -> &'static str { "articles" }
fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
fn new_fields() -> Self::Fields { ArticleFields }
}
let view = ListView::<Article>::new();
assert!(view.get_context_object_name().is_none());Sourcepub fn with_serializer(
self,
serializer: Box<dyn Serializer<Input = T, Output = String> + Send + Sync>,
) -> Self
pub fn with_serializer( self, serializer: Box<dyn Serializer<Input = T, Output = String> + Send + Sync>, ) -> Self
Sets a custom serializer for the view.
Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_rest::serializers::JsonSerializer;
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};
#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
id: Option<i64>,
title: String,
}
#[derive(Clone)]
struct ArticleFields;
impl reinhardt_db::orm::FieldSelector for ArticleFields {
fn with_alias(self, _alias: &str) -> Self {
self
}
}
impl Model for Article {
type PrimaryKey = i64;
type Fields = ArticleFields;
fn table_name() -> &'static str { "articles" }
fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
fn new_fields() -> Self::Fields { ArticleFields }
}
let view = ListView::<Article>::new()
.with_serializer(Box::new(JsonSerializer::<Article>::new()));Sourcepub fn with_objects(self, objects: Vec<T>) -> Self
pub fn with_objects(self, objects: Vec<T>) -> Self
Sets the list of objects to display in the view.
Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};
#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
id: Option<i64>,
title: String,
}
#[derive(Clone)]
struct ArticleFields;
impl reinhardt_db::orm::FieldSelector for ArticleFields {
fn with_alias(self, _alias: &str) -> Self {
self
}
}
impl Model for Article {
type PrimaryKey = i64;
type Fields = ArticleFields;
fn table_name() -> &'static str { "articles" }
fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
fn new_fields() -> Self::Fields { ArticleFields }
}
let articles = vec![
Article { id: Some(1), title: "First".to_string() },
Article { id: Some(2), title: "Second".to_string() },
];
let view = ListView::<Article>::new()
.with_objects(articles.clone());
let objects = view.get_objects().await.unwrap();
assert_eq!(objects.len(), 2);
assert_eq!(objects[0].title, "First");Sourcepub fn with_ordering(self, ordering: Vec<String>) -> Self
pub fn with_ordering(self, ordering: Vec<String>) -> Self
Sets the ordering for the object list.
Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};
#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
id: Option<i64>,
title: String,
}
#[derive(Clone)]
struct ArticleFields;
impl reinhardt_db::orm::FieldSelector for ArticleFields {
fn with_alias(self, _alias: &str) -> Self {
self
}
}
impl Model for Article {
type PrimaryKey = i64;
type Fields = ArticleFields;
fn table_name() -> &'static str { "articles" }
fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
fn new_fields() -> Self::Fields { ArticleFields }
}
let view = ListView::<Article>::new()
.with_ordering(vec!["-created_at".to_string(), "title".to_string()]);
assert_eq!(view.get_ordering(), Some(vec!["-created_at".to_string(), "title".to_string()]));Sourcepub fn with_paginate_by(self, paginate_by: usize) -> Self
pub fn with_paginate_by(self, paginate_by: usize) -> Self
Sets the number of items per page.
Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};
#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
id: Option<i64>,
title: String,
}
#[derive(Clone)]
struct ArticleFields;
impl reinhardt_db::orm::FieldSelector for ArticleFields {
fn with_alias(self, _alias: &str) -> Self {
self
}
}
impl Model for Article {
type PrimaryKey = i64;
type Fields = ArticleFields;
fn table_name() -> &'static str { "articles" }
fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
fn new_fields() -> Self::Fields { ArticleFields }
}
let view = ListView::<Article>::new()
.with_paginate_by(25);
assert_eq!(view.get_paginate_by(), Some(25));Sourcepub fn with_allow_empty(self, allow_empty: bool) -> Self
pub fn with_allow_empty(self, allow_empty: bool) -> Self
Sets whether to allow empty result sets.
When set to false, the view will return an error if no objects are found.
Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};
#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
id: Option<i64>,
title: String,
}
#[derive(Clone)]
struct ArticleFields;
impl reinhardt_db::orm::FieldSelector for ArticleFields {
fn with_alias(self, _alias: &str) -> Self {
self
}
}
impl Model for Article {
type PrimaryKey = i64;
type Fields = ArticleFields;
fn table_name() -> &'static str { "articles" }
fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
fn new_fields() -> Self::Fields { ArticleFields }
}
let view = ListView::<Article>::new()
.with_allow_empty(false);
assert!(!view.allow_empty());Sourcepub fn with_context_object_name(self, name: impl Into<String>) -> Self
pub fn with_context_object_name(self, name: impl Into<String>) -> Self
Sets a custom name for the object list in the context.
Examples
use reinhardt_views::{ListView, MultipleObjectMixin};
use reinhardt_db::orm::Model;
use serde::{Serialize, Deserialize};
#[derive(Debug, Clone, Serialize, Deserialize)]
struct Article {
id: Option<i64>,
title: String,
}
#[derive(Clone)]
struct ArticleFields;
impl reinhardt_db::orm::FieldSelector for ArticleFields {
fn with_alias(self, _alias: &str) -> Self {
self
}
}
impl Model for Article {
type PrimaryKey = i64;
type Fields = ArticleFields;
fn table_name() -> &'static str { "articles" }
fn primary_key(&self) -> Option<Self::PrimaryKey> { self.id }
fn set_primary_key(&mut self, value: Self::PrimaryKey) { self.id = Some(value); }
fn new_fields() -> Self::Fields { ArticleFields }
}
let view = ListView::<Article>::new()
.with_context_object_name("articles");
assert_eq!(view.get_context_object_name(), Some("articles"));Trait Implementations
Sourceimpl<T> MultipleObjectMixin<T> for ListView<T>
impl<T> MultipleObjectMixin<T> for ListView<T>
Sourcefn get_objects<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<T>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_objects<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<T>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Get objects for this view
Sourcefn allow_empty(&self) -> bool
fn allow_empty(&self) -> bool
Whether to allow empty result sets
Sourcefn get_paginate_by(&self) -> Option<usize>
fn get_paginate_by(&self) -> Option<usize>
Get the number of items per page
Sourcefn get_context_object_name(&self) -> Option<&str>
fn get_context_object_name(&self) -> Option<&str>
Get the context object name
Sourceimpl<T> View for ListView<T>
impl<T> View for ListView<T>
fn dispatch<'life0, 'async_trait>(
&'life0 self,
request: Request,
) -> Pin<Box<dyn Future<Output = Result<Response>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourcefn allowed_methods(&self) -> Vec<&'static str>
fn allowed_methods(&self) -> Vec<&'static str>
Returns the list of HTTP methods allowed by this view